@@ -23,7 +23,7 @@ strs <- map_chr(seq_len(length(headings) - 1), function(i) {
       tolower() %>% 
       str_replace_all(" ", "-") %>%
       str_replace_all("[^a-z\\-_]", "") %>% 
-      str_replace("^-*", "functionality.md#")
+      str_replace("^-*", "#")
     
     paste0(
       gsub("## ", "* ", head), ": \n",
